## $Id: browser.py 10088 2013-04-22 05:20:58Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.futminna.applicants.interfaces import (
    ICustomUGApplicant,
    ICustomPGApplicant,
    ICustomPGApplicantEdit,
    ICustomUGApplicantEdit,
    UG_OMIT_DISPLAY_FIELDS,
    UG_OMIT_PDF_FIELDS,
    UG_OMIT_MANAGE_FIELDS,
    UG_OMIT_EDIT_FIELDS,
    PG_OMIT_DISPLAY_FIELDS,
    PG_OMIT_PDF_FIELDS,
    PG_OMIT_MANAGE_FIELDS,
    PG_OMIT_EDIT_FIELDS,
    )
from kofacustom.nigeria.applicants.browser import (
    NigeriaApplicantDisplayFormPage,
    NigeriaApplicantManageFormPage,
    NigeriaApplicantEditFormPage,
    NigeriaPDFApplicationSlip)


class CustomApplicantDisplayFormPage(NigeriaApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    grok.template('applicantdisplaypage')

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['perm_address'].custom_widget = BytesDisplayWidget
        form_fields['notice'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue'):
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date'):
            form_fields = form_fields.omit('screening_date')
        return form_fields

class CustomPDFApplicationSlip(NigeriaPDFApplicationSlip):

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue'):
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date'):
            form_fields = form_fields.omit('screening_date')
        return form_fields

class CustomApplicantManageFormPage(NigeriaApplicantManageFormPage):
    """A full edit view for applicant data.
    """
    
    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicant)
            for field in PG_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['student_id'].for_display = True
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(NigeriaApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(ICustomPGApplicantEdit)
            for field in PG_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicantEdit)
            for field in UG_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields
